@@ -1,7 +1,7 @@
 // qjackctlGraphForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -96,7 +96,7 @@ qjackctlGraphForm::qjackctlGraphForm (
 	zoom_widget->setToolTip(tr("Zoom"));
 
 	QHBoxLayout *zoom_layout = new QHBoxLayout();
-	zoom_layout->setMargin(0);
+	zoom_layout->setContentsMargins(0, 0, 0, 0);
 	zoom_layout->setSpacing(2);
 
 	QToolButton *zoom_out = new QToolButton();
@@ -230,15 +230,48 @@ qjackctlGraphForm::qjackctlGraphForm (
 	m_ui.viewColorsAlsaMidiAction->setData(qjackctlAlsaGraph::midiPortType());
 #endif
 
+	int iAddSeparator = 0;
+#ifdef CONFIG_JACK_CV
+	m_ui.viewColorsJackCvAction->setData(qjackctlJackGraph::cvPortType());
+	++iAddSeparator;
+#endif
+#ifdef CONFIG_JACK_OSC
+	m_ui.viewColorsJackOscAction->setData(qjackctlJackGraph::oscPortType());
+	++iAddSeparator;
+#endif
+	if (iAddSeparator > 0)
+		m_ui.viewColorsMenu->insertSeparator(m_ui.viewColorsResetAction);
+
 	QObject::connect(m_ui.viewColorsJackAudioAction,
 		SIGNAL(triggered(bool)),
 		SLOT(viewColorsAction()));
 	QObject::connect(m_ui.viewColorsJackMidiAction,
 		SIGNAL(triggered(bool)),
 		SLOT(viewColorsAction()));
+#ifdef CONFIG_ALSA_SEQ
 	QObject::connect(m_ui.viewColorsAlsaMidiAction,
 		SIGNAL(triggered(bool)),
 		SLOT(viewColorsAction()));
+#else
+	m_ui.viewColorsMenu->removeAction(m_ui.viewColorsAlsaMidiAction);
+	m_ui.viewColorsAlsaMidiAction->setDisabled(true);
+#endif
+#ifdef CONFIG_JACK_CV
+	QObject::connect(m_ui.viewColorsJackCvAction,
+		SIGNAL(triggered(bool)),
+		SLOT(viewColorsAction()));
+#else
+	m_ui.viewColorsMenu->removeAction(m_ui.viewColorsJackCvAction);
+	m_ui.viewColorsJackCvAction->setDisabled(true);
+#endif
+#ifdef CONFIG_JACK_OSC
+	QObject::connect(m_ui.viewColorsJackOscAction,
+		SIGNAL(triggered(bool)),
+		SLOT(viewColorsAction()));
+#else
+	m_ui.viewColorsMenu->removeAction(m_ui.viewColorsJackOscAction);
+	m_ui.viewColorsJackOscAction->setDisabled(true);
+#endif
 	QObject::connect(m_ui.viewColorsResetAction,
 		SIGNAL(triggered(bool)),
 		SLOT(viewColorsReset()));
@@ -841,7 +874,15 @@ void qjackctlGraphForm::updateViewColors (void)
 {
 	updateViewColorsAction(m_ui.viewColorsJackAudioAction);
 	updateViewColorsAction(m_ui.viewColorsJackMidiAction);
+#ifdef CONFIG_ALSA_SEQ
 	updateViewColorsAction(m_ui.viewColorsAlsaMidiAction);
+#endif
+#ifdef CONFIG_JACK_CV
+	updateViewColorsAction(m_ui.viewColorsJackCvAction);
+#endif
+#ifdef CONFIG_JACK_OSC
+	updateViewColorsAction(m_ui.viewColorsJackOscAction);
+#endif
 }
 
 
