@@ -1,7 +1,7 @@
 // qjackctlMessagesStatusForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -37,10 +37,14 @@
 #include <QShowEvent>
 #include <QHideEvent>
 
-
 // The maximum number of message lines.
 #define QJACKCTL_MESSAGES_MAXLINES  1000
 
+// Deprecated QTextStreamFunctions/Qt namespaces workaround.
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#define endl	Qt::endl
+#endif
+
 
 //----------------------------------------------------------------------------
 // qjackctlMessagesStatusForm -- UI wrapper form.
@@ -186,7 +190,7 @@ QFont qjackctlMessagesStatusForm::messagesFont (void) const
 	return m_ui.MessagesTextView->font();
 }
 
-void qjackctlMessagesStatusForm::setMessagesFont ( const QFont & font )
+void qjackctlMessagesStatusForm::setMessagesFont ( const QFont& font )
 {
 	m_ui.MessagesTextView->setFont(font);
 }
@@ -271,14 +275,14 @@ void qjackctlMessagesStatusForm::appendMessagesLine ( const QString& s )
 
 void qjackctlMessagesStatusForm::appendMessages ( const QString& s )
 {
-	appendMessagesColor(s, "#999999");
+	appendMessagesColor(s, Qt::gray);
 }
 
-void qjackctlMessagesStatusForm::appendMessagesColor ( const QString& s, const QString& c )
+void qjackctlMessagesStatusForm::appendMessagesColor ( const QString& s, const QColor& rgb )
 {
-	QString sText = QTime::currentTime().toString("hh:mm:ss.zzz") + ' ' + s;
-	
-	appendMessagesLine("<font color=\"" + c + "\">" + sText + "</font>");
+	const QString& sText
+		= QTime::currentTime().toString("hh:mm:ss.zzz") + ' ' + s;
+	appendMessagesLine("<font color=\"" + rgb.name() + "\">" + sText + "</font>");
 	appendMessagesLog(sText);
 }
 
