@@ -1,7 +1,7 @@
 // qjackctlPaletteForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -75,6 +75,9 @@ static struct
 	{ "LinkVisited",     QPalette::LinkVisited     },
 	{ "ToolTipBase",     QPalette::ToolTipBase     },
 	{ "ToolTipText",     QPalette::ToolTipText     },
+#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
+	{ "PlaceholderText", QPalette::PlaceholderText },
+#endif
 	{ "NoRole",          QPalette::NoRole          },
 
 	{  nullptr,          QPalette::NoRole          }
@@ -112,9 +115,6 @@ qjackctlPaletteForm::qjackctlPaletteForm ( QWidget *parent, const QPalette& pal
 	m_ui.paletteView->setColumnHidden(2, true);
 	m_ui.paletteView->setColumnHidden(3, true);
 
-	QObject::connect(m_ui.nameCombo,
-		SIGNAL(activated(const QString&)),
-		SLOT(nameComboActivated(const QString&)));
 	QObject::connect(m_ui.nameCombo,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(nameComboChanged(const QString&)));
@@ -226,18 +226,14 @@ QSettings *qjackctlPaletteForm::settings (void) const
 }
 
 
-void qjackctlPaletteForm::nameComboActivated ( const QString& name )
-{
-	setPaletteName(name);
-}
-
-
 void qjackctlPaletteForm::nameComboChanged ( const QString& name )
 {
-	if (m_dirtyCount > 0 || m_ui.nameCombo->findText(name) < 0)
+	if (m_dirtyCount > 0 || m_ui.nameCombo->findText(name) < 0) {
 		updateDialogButtons();
-	else
+	} else {
 		setPaletteName(name);
+		++m_dirtyTotal;
+	}
 }
 
 
@@ -513,7 +509,9 @@ bool qjackctlPaletteForm::namedPalette (
 	QSettings *settings, const QString& name, QPalette& pal, bool fixup )
 {
 	int result = 0;
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	uint mask = pal.resolve();
+#endif
 
 	// Custom color themes...
 	if (name == "Wonton Soup") {
@@ -574,7 +572,9 @@ bool qjackctlPaletteForm::namedPalette (
 		pal.setColor(QPalette::Active,   QPalette::LinkVisited, QColor(64, 128, 255));
 		pal.setColor(QPalette::Inactive, QPalette::LinkVisited, QColor(64, 128, 255));
 		pal.setColor(QPalette::Disabled, QPalette::LinkVisited, QColor(54, 76, 119));
+	#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 		mask = 0;
+	#endif
 		++result;
 	}
 	else
@@ -636,7 +636,9 @@ bool qjackctlPaletteForm::namedPalette (
 		pal.setColor(QPalette::Active,   QPalette::LinkVisited, QColor(230, 100, 230));
 		pal.setColor(QPalette::Inactive, QPalette::LinkVisited, QColor(230, 100, 230));
 		pal.setColor(QPalette::Disabled, QPalette::LinkVisited, QColor(74, 34, 74));
+	#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 		mask = 0;
+	#endif
 		++result;
 	}
 	else
@@ -654,7 +656,9 @@ bool qjackctlPaletteForm::namedPalette (
 				pal.setColor(QPalette::Active,   cr, QColor(clist.at(0)));
 				pal.setColor(QPalette::Inactive, cr, QColor(clist.at(1)));
 				pal.setColor(QPalette::Disabled, cr, QColor(clist.at(2)));
+			#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 				mask &= ~(1 << int(cr));
+			#endif
 				++result;
 			}
 		}
@@ -693,7 +697,9 @@ bool qjackctlPaletteForm::namedPalette (
 		++result;
 	}
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	pal.resolve(mask);
+#endif
 	return (result > 0);
 }
 
@@ -964,22 +970,22 @@ bool qjackctlPaletteForm::PaletteModel::setData (
 		if (m_generate) {
 			m_palette.setBrush(QPalette::Inactive, cr, color);
 			switch (cr) {
-				case QPalette::Foreground:
+				case QPalette::WindowText:
 				case QPalette::Text:
 				case QPalette::ButtonText:
 				case QPalette::Base:
 					break;
 				case QPalette::Dark:
-					m_palette.setBrush(QPalette::Disabled, QPalette::Foreground, color);
+					m_palette.setBrush(QPalette::Disabled, QPalette::WindowText, color);
 					m_palette.setBrush(QPalette::Disabled, QPalette::Dark, color);
 					m_palette.setBrush(QPalette::Disabled, QPalette::Text, color);
 					m_palette.setBrush(QPalette::Disabled, QPalette::ButtonText, color);
 					index_begin = PaletteModel::index(0, 0);
 					index_end = PaletteModel::index(m_nrows - 1, 3);
 					break;
-				case QPalette::Background:
+				case QPalette::Window:
 					m_palette.setBrush(QPalette::Disabled, QPalette::Base, color);
-					m_palette.setBrush(QPalette::Disabled, QPalette::Background, color);
+					m_palette.setBrush(QPalette::Disabled, QPalette::Window, color);
 					index_begin = PaletteModel::index(QPalette::Base, 0);
 					break;
 				case QPalette::Highlight:
@@ -1258,7 +1264,7 @@ qjackctlPaletteForm::ColorEditor::ColorEditor ( QWidget *parent )
 	: QWidget(parent)
 {
 	QLayout *layout = new QHBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	m_button = new qjackctlPaletteForm::ColorButton(this);
 	layout->addWidget(m_button);
 	QObject::connect(m_button,
@@ -1304,7 +1310,7 @@ qjackctlPaletteForm::RoleEditor::RoleEditor ( QWidget *parent )
 	m_edited = false;
 
 	QHBoxLayout *layout = new QHBoxLayout(this);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	layout->setSpacing(0);
 
 	m_label = new QLabel(this);
