@@ -1,7 +1,7 @@
 // qjackctlPatchbayForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,8 @@ class qjackctlPatchbayForm : public QWidget
 public:
 
 	// Constructor.
-	qjackctlPatchbayForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qjackctlPatchbayForm(QWidget *pParent = nullptr,
+		Qt::WindowFlags wflags = Qt::WindowFlags());
 	// Destructor.
 	~qjackctlPatchbayForm();
 
