@@ -39,6 +39,11 @@
 #include <QProcess>
 #include <QElapsedTimer>
 
+// Deprecated QTextStreamFunctions/Qt namespaces workaround.
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#define endl	Qt::endl
+#endif
+
 
 //----------------------------------------------------------------------------
 // qjackctlSession -- JACK session container.
@@ -240,10 +245,15 @@ bool qjackctlSession::load ( const QString& sSessionDir )
 			sCommand.replace("${SESSION_DIR}", sClientDir);
 		}
 		// Launch command and wait a litle bit before continue...
-		if (!sCommand.isEmpty() && QProcess::startDetached(sCommand)) {
-			QElapsedTimer timer; timer.start();
-			while (timer.elapsed() < 200)
-				QApplication::processEvents();
+		if (!sCommand.isEmpty()) {
+			QStringList cmd_args = sCommand.split(' ');
+			sCommand = cmd_args.at(0);
+			cmd_args.removeAt(0);
+			if (QProcess::startDetached(sCommand, cmd_args)) {
+				QElapsedTimer timer; timer.start();
+				while (timer.elapsed() < 200)
+					QApplication::processEvents();
+			}
 		}
 	}
 
