@@ -1,7 +1,7 @@
 // qjackctlSessionForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -94,7 +94,7 @@ qjackctlSessionInfraClientItemEditor::qjackctlSessionInfraClientItemEditor (
 
 	QHBoxLayout *pLayout = new QHBoxLayout();
 	pLayout->setSpacing(0);
-	pLayout->setMargin(0);
+	pLayout->setContentsMargins(0, 0, 0, 0);
 	pLayout->addWidget(m_pItemEdit);
 	if (m_pBrowseButton)
 		pLayout->addWidget(m_pBrowseButton);
