@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -31,7 +31,10 @@
 #include <QFileInfo>
 
 #include <QApplication>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QDesktopWidget>
+#endif
 
 #ifdef CONFIG_JACK_VERSION
 #include <jack/jack.h>
@@ -419,6 +422,8 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 	preset.iPortMax     = m_settings.value("/PortMax", 256).toInt();
 	preset.sMidiDriver  = m_settings.value("/MidiDriver").toString();
 	preset.sServerSuffix = m_settings.value("/ServerSuffix").toString();
+	preset.uClockSource = m_settings.value("/ClockSource", 0).toUInt();
+	preset.ucSelfConnectMode = m_settings.value("/SelfConnectMode", ' ').value<uchar>();
 	m_settings.endGroup();
 
 #ifdef CONFIG_JACK_MIDI
@@ -476,6 +481,8 @@ bool qjackctlSetup::savePreset ( qjackctlPreset& preset, const QString& sPreset
 	m_settings.setValue("/PortMax",     preset.iPortMax);
 	m_settings.setValue("/MidiDriver",  preset.sMidiDriver);
 	m_settings.setValue("/ServerSuffix", preset.sServerSuffix);
+	m_settings.setValue("/ClockSource", preset.uClockSource);
+	m_settings.setValue("/SelfConnectMode", preset.ucSelfConnectMode);
 	m_settings.endGroup();
 
 	return true;
@@ -737,8 +744,10 @@ void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 			QWidget *pParent = pWidget->parentWidget();
 			if (pParent)
 				pParent = pParent->window();
+		#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 			if (pParent == nullptr)
 				pParent = QApplication::desktop();
+		#endif
 			if (pParent) {
 				QRect wrect(pWidget->geometry());
 				wrect.moveCenter(pParent->geometry().center());
