@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -72,9 +72,8 @@ static const char *g_pszDefName = QT_TRANSLATE_NOOP("qjackctlSetupForm", "(defau
 // qjackctlSetupForm -- UI wrapper form.
 
 // Constructor.
-qjackctlSetupForm::qjackctlSetupForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QDialog(pParent, wflags)
+qjackctlSetupForm::qjackctlSetupForm ( QWidget *pParent )
+	: QDialog(pParent)
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
@@ -82,6 +81,11 @@ qjackctlSetupForm::qjackctlSetupForm (
 	// No settings descriptor initially (the caller will set it).
 	m_pSetup = nullptr;
 
+	QMessageBox mbox;
+	mbox.setIcon(QMessageBox::Warning);
+	m_ui.AdvancedIconLabel->setPixmap(
+		mbox.iconPixmap().scaledToHeight(16, Qt::SmoothTransformation));
+
 	// Setup time-display radio-button group.
 	m_pTimeDisplayButtonGroup = new QButtonGroup(this);
 	m_pTimeDisplayButtonGroup->addButton(m_ui.TransportTimeRadioButton, 0);
@@ -90,6 +94,31 @@ qjackctlSetupForm::qjackctlSetupForm (
 	m_pTimeDisplayButtonGroup->addButton(m_ui.ElapsedXrunRadioButton,   3);
 	m_pTimeDisplayButtonGroup->setExclusive(true);
 
+	// Setup clock-source combo-box.
+	m_ui.ClockSourceComboBox->clear();
+	m_ui.ClockSourceComboBox->addItem(g_pszDefName, uint(0));
+	m_ui.ClockSourceComboBox->addItem(tr("System"), uint('s'));
+	m_ui.ClockSourceComboBox->addItem(tr("Cycle"),  uint('c'));
+	m_ui.ClockSourceComboBox->addItem(tr("HPET"),   uint('h'));
+
+	// Setup self-connect-mode combo-box.
+	m_ui.SelfConnectModeComboBox->clear();
+	m_ui.SelfConnectModeComboBox->addItem(
+		tr("Don't restrict self connect requests (default)"),
+		QVariant::fromValue<uchar> (' '));
+	m_ui.SelfConnectModeComboBox->addItem(
+		tr("Fail self connect requests to external ports only"),
+		QVariant::fromValue<uchar> ('E'));
+	m_ui.SelfConnectModeComboBox->addItem(
+		tr("Ignore self connect requests to external ports only"),
+		QVariant::fromValue<uchar> ('e'));
+	m_ui.SelfConnectModeComboBox->addItem(
+		tr("Fail all self connect requests"),
+		QVariant::fromValue<uchar> ('A'));
+	m_ui.SelfConnectModeComboBox->addItem(
+		tr("Ignore all self connect requests"),
+		QVariant::fromValue<uchar> ('a'));
+
 	// Initialize dirty control state.
 	m_iDirtySetup = 0;
 	m_iDirtyPreset = 0;
@@ -99,7 +128,7 @@ qjackctlSetupForm::qjackctlSetupForm (
 
 	// Set dialog validators...
 	m_ui.PresetComboBox->setValidator(
-		new QRegExpValidator(QRegExp("[\\w-]+"), m_ui.PresetComboBox));
+		new QRegularExpressionValidator(QRegularExpression("[\\w-]+"), m_ui.PresetComboBox));
 	m_ui.FramesComboBox->setValidator(
 		new QIntValidator(m_ui.FramesComboBox));
 	m_ui.SampleRateComboBox->setValidator(
@@ -172,6 +201,12 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.UnlockMemCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(settingsChanged()));
+	QObject::connect(m_ui.ClockSourceComboBox,
+		SIGNAL(activated(int)),
+		SLOT(settingsChanged()));
+	QObject::connect(m_ui.SelfConnectModeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(settingsChanged()));
 	QObject::connect(m_ui.SyncCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(settingsChanged()));
@@ -492,6 +527,21 @@ void qjackctlSetupForm::setComboBoxCurrentText (
 }
 
 
+// A combo-box text data setter helper.
+void qjackctlSetupForm::setComboBoxCurrentData (
+	QComboBox *pComboBox, const QVariant& data ) const
+{
+	if (pComboBox->isEditable()) {
+		pComboBox->setEditText(data.toString());
+	} else {
+		int iIndex = pComboBox->findData(data);
+		if (iIndex < 0)
+			iIndex = 0;
+		pComboBox->setCurrentIndex(iIndex);
+	}
+}
+
+
 // Populate (setup) dialog controls from settings descriptors.
 void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 {
@@ -576,7 +626,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 		|| !font.fromString(m_pSetup->sMessagesFont))
 		font = QFont("Monospace", 8);
 	pal = m_ui.MessagesFontTextLabel->palette();
-	pal.setColor(QPalette::Background, pal.base().color());
+	pal.setColor(QPalette::Window, pal.base().color());
 	m_ui.MessagesFontTextLabel->setPalette(pal);
 	m_ui.MessagesFontTextLabel->setFont(font);
 	m_ui.MessagesFontTextLabel->setText(
@@ -586,7 +636,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 		|| !font.fromString(m_pSetup->sConnectionsFont))
 		font = QFont(sSansSerif, 10);
 	pal = m_ui.ConnectionsFontTextLabel->palette();
-	pal.setColor(QPalette::Background, pal.base().color());
+	pal.setColor(QPalette::Window, pal.base().color());
 	m_ui.ConnectionsFontTextLabel->setPalette(pal);
 	m_ui.ConnectionsFontTextLabel->setFont(font);
 	m_ui.ConnectionsFontTextLabel->setText(
@@ -728,6 +778,8 @@ void qjackctlSetupForm::setCurrentPreset ( const qjackctlPreset& preset )
 	m_ui.DitherComboBox->setCurrentIndex(preset.iDither);
 	setComboBoxCurrentText(m_ui.TimeoutComboBox,
 		QString::number(preset.iTimeout));
+	setComboBoxCurrentData(m_ui.ClockSourceComboBox,
+		uint(preset.uClockSource));
 	setComboBoxCurrentText(m_ui.InDeviceComboBox,
 		preset.sInDevice.isEmpty()
 			? m_pSetup->sDefPresetName
@@ -742,6 +794,8 @@ void qjackctlSetupForm::setCurrentPreset ( const qjackctlPreset& preset )
 	m_ui.OutLatencySpinBox->setValue(preset.iOutLatency);
 	m_ui.StartDelaySpinBox->setValue(preset.iStartDelay);
 	m_ui.SyncCheckBox->setChecked(preset.bSync);
+	setComboBoxCurrentData(m_ui.SelfConnectModeComboBox,
+		QVariant::fromValue<uchar> (preset.ucSelfConnectMode));
 	m_ui.VerboseCheckBox->setChecked(preset.bVerbose);
 	setComboBoxCurrentText(m_ui.PortMaxComboBox,
 		QString::number(preset.iPortMax));
@@ -801,6 +855,16 @@ bool qjackctlSetupForm::getCurrentPreset ( qjackctlPreset& preset )
 	if (preset.sOutDevice == m_pSetup->sDefPresetName)
 		preset.sOutDevice.clear();
 
+	preset.uClockSource = 0;
+	int iIndex = m_ui.ClockSourceComboBox->currentIndex();
+	if (iIndex >= 0)
+		preset.uClockSource = m_ui.ClockSourceComboBox->itemData(iIndex).toUInt();
+
+	preset.ucSelfConnectMode = ' ';
+	iIndex = m_ui.SelfConnectModeComboBox->currentIndex();
+	if (iIndex >= 0)
+		preset.ucSelfConnectMode = m_ui.SelfConnectModeComboBox->itemData(iIndex).value<uchar> ();
+
 	return true;
 }
 
@@ -1074,6 +1138,12 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 
 	m_ui.SyncCheckBox->setEnabled(bJackDBus);
 
+	m_ui.ClockSourceTextLabel->setEnabled(bJackDBus);
+	m_ui.ClockSourceComboBox->setEnabled(bJackDBus);
+
+	m_ui.SelfConnectModeTextLabel->setEnabled(bJackDBus);
+	m_ui.SelfConnectModeComboBox->setEnabled(bJackDBus);
+
 	m_ui.NoMemLockCheckBox->setEnabled(!bCoreaudio && !bJackDBus);
 	m_ui.UnlockMemCheckBox->setEnabled(!bCoreaudio && !bJackDBus
 		&& !m_ui.NoMemLockCheckBox->isChecked());
@@ -1255,9 +1325,9 @@ void qjackctlSetupForm::stabilizeForm (void)
 
 	changeDriverUpdate(m_ui.DriverComboBox->currentText(), false);
 
-	bValid = (bValid || m_iDirtyBuffSize > 0);
-	m_ui.DialogButtonBox->button(QDialogButtonBox::Apply)->setEnabled(bValid);
-	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
+	bEnabled = (bValid || m_iDirtyBuffSize > 0);
+	m_ui.DialogButtonBox->button(QDialogButtonBox::Apply)->setEnabled(bEnabled);
+	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bEnabled);
 }
 
 
@@ -1459,12 +1529,12 @@ void qjackctlSetupForm::chooseDisplayFont2 (void)
 void qjackctlSetupForm::toggleDisplayEffect ( bool bOn )
 {
 	QPalette pal;
-	pal.setColor(QPalette::Foreground, Qt::green);
+	pal.setColor(QPalette::WindowText, Qt::green);
 	if (bOn) {
 		QPixmap pm(":/images/displaybg1.png");
-		pal.setBrush(QPalette::Background, QBrush(pm));
+		pal.setBrush(QPalette::Window, QBrush(pm));
 	} else {
-		pal.setColor(QPalette::Background, Qt::black);
+		pal.setColor(QPalette::Window, Qt::black);
 	}
 	m_ui.DisplayFont1TextLabel->setPalette(pal);
 	m_ui.DisplayFont2TextLabel->setPalette(pal);
@@ -1612,13 +1682,6 @@ void qjackctlSetupForm::apply (void)
 	if (pMainForm == nullptr)
 		return;
 
-	if (m_iDirtySettings > 0 || m_iDirtyPreset > 0) {
-		// Save current preset selection.
-		m_pSetup->sDefPreset = m_ui.PresetComboBox->currentText();
-		// Always save current settings...
-		savePreset(m_pSetup->sDefPreset);
-	}
-	else
 	if (m_iDirtyBuffSize > 0) {
 		// Change JACK buffer size immediately...
 		if (!pMainForm->resetBuffSize(jack_nframes_t(
@@ -1626,8 +1689,13 @@ void qjackctlSetupForm::apply (void)
 			// Make up a settings change instead...
 			++m_iDirtySettings;
 		}
-		// We're not dirty anymore...
-		m_iDirtyBuffSize = 0;
+	}
+
+	if (m_iDirtySettings > 0 || m_iDirtyPreset > 0 || m_iDirtyBuffSize > 0) {
+		// Save current preset selection.
+		m_pSetup->sDefPreset = m_ui.PresetComboBox->currentText();
+		// Always save current settings...
+		savePreset(m_pSetup->sDefPreset);
 	}
 
 	if (m_iDirtyOptions > 0) {
@@ -1854,6 +1922,7 @@ void qjackctlSetupForm::apply (void)
 	// Reset all dirty flags...
 	m_iDirtyPreset = 0;
 	m_iDirtySettings = 0;
+	m_iDirtyBuffSize = 0;
 	m_iDirtyOptions = 0;
 
 	// Make it stable anyway...
@@ -1908,7 +1977,7 @@ bool qjackctlSetupForm::queryClose (void)
 	bool bQueryClose = true;
 
 	// Check if there's any pending changes...
-	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0) {
+	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0 || m_iDirtyBuffSize > 0) {
 		switch (QMessageBox::warning(isVisible() ? this : parentWidget(),
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Some settings have been changed.\n\n"
@@ -1917,12 +1986,9 @@ bool qjackctlSetupForm::queryClose (void)
 			QMessageBox::Discard |
 			QMessageBox::Cancel)) {
 		case QMessageBox::Apply:
-			accept();
+			apply();
 			// Fall thru...
 		case QMessageBox::Discard:
-			// Reset dirty flags...
-			m_iDirtySettings = 0;
-			m_iDirtyOptions = 0;
 			break;
 		default:    // Cancel.
 			bQueryClose = false;
