@@ -1,7 +1,7 @@
 // qjackctlSetupForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,7 +42,7 @@ class qjackctlSetupForm : public QDialog
 public:
 
 	// Constructor.
-	qjackctlSetupForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qjackctlSetupForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qjackctlSetupForm();
 
@@ -94,9 +94,11 @@ protected slots:
 
 protected:
 
-	// A combo-box text item setter helper.
+	// A combo-box text/data item setter helper.
 	void setComboBoxCurrentText (
 		QComboBox *pComboBox, const QString& sText ) const;
+	void setComboBoxCurrentData (
+		QComboBox *pComboBox, const QVariant& data ) const;
 
 	void setCurrentPreset(const qjackctlPreset& preset);
 	bool getCurrentPreset(qjackctlPreset& preset);
