@@ -1,7 +1,7 @@
 // qjackctlSocketForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,9 +28,9 @@
 #include "qjackctlAliases.h"
 
 #include <QMessageBox>
+#include <QRegularExpression>
 #include <QButtonGroup>
 #include <QHeaderView>
-#include <QRegExp>
 #include <QPixmap>
 #include <QMenu>
 
@@ -39,9 +39,8 @@
 // qjackctlSocketForm -- UI wrapper form.
 
 // Constructor.
-qjackctlSocketForm::qjackctlSocketForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QDialog(pParent, wflags)
+qjackctlSocketForm::qjackctlSocketForm ( QWidget *pParent )
+	: QDialog(pParent)
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
@@ -917,7 +916,7 @@ void qjackctlSocketForm::clientNameChanged (void)
 		if (!sSocketName.isEmpty()) {
 			int iSocketNo = 0;
 			QString sSocketMask = sSocketName;
-			sSocketMask.remove(QRegExp("[ |0-9]+$")).append(" %1");
+			sSocketMask.remove(QRegularExpression("[ |0-9]+$")).append(" %1");
 			do { sSocketName = sSocketMask.arg(++iSocketNo); }
 			while (m_pSocketList->findSocket(sSocketName, iSocketType));
 			m_ui.SocketNameLineEdit->setText(sSocketName);
